@@ -28,7 +28,7 @@
 #include <sys/types.h>
 #include <netinet/in.h>
 
-#define LIBCITADEL_VERSION_NUMBER	824
+#define LIBCITADEL_VERSION_NUMBER	901
 
 /*
  * Here's a bunch of stupid magic to make the MIME parser portable.
@@ -49,16 +49,16 @@ typedef enum AXLevel {
 }eUsrAxlvl;
 
 typedef enum __RoomNetCfg {
-	subpending,
-	unsubpending,
-	lastsent, /* Server internal use only */
-	ignet_push_share,
-	listrecp,
-	digestrecp,
-	pop3client,
-	rssclient,
-	participate,
-	roommailalias,
+	subpending        = 0,
+	unsubpending      = 1,
+	lastsent          = 2, /* Server internal use only */
+	ignet_push_share  = 3,
+	listrecp          = 4,
+	digestrecp        = 5,
+	pop3client        = 6,
+	rssclient         = 7,
+	participate       = 8,
+	roommailalias     = 9,
 	maxRoomNetCfg
 } RoomNetCfg;
 
@@ -100,6 +100,7 @@ typedef enum _room_views {
 	VIEW_DRAFTS		= 9,	/* Drafts view */
 	VIEW_BLOG		= 10,	/* Blog view */
 	VIEW_QUEUE		= 11,   /* SMTP/... QUEUE rooms */
+	VIEW_WIKIMD		= 12,	/* Markdown Wiki view */
 	VIEW_MAX,
 	VIEW_JSON_LIST,
 } ROOM_VIEWS;
@@ -107,7 +108,7 @@ typedef enum _room_views {
 #define BLOG_EUIDBUF_SIZE	40
 
 #ifndef IsEmptyStr
-#define IsEmptyStr(a) ((a)[0] == '\0')
+#define IsEmptyStr(a) ( ( (a) == NULL ) || ((a)[0] == '\0') )
 #endif
 
 
@@ -337,8 +338,23 @@ void StrBuf_RFC822_2_Utf8(StrBuf *Target,
 /* deprecated old version: */
 void StrBuf_RFC822_to_Utf8(StrBuf *Target, const StrBuf *DecodeMe, const StrBuf* DefaultCharset, StrBuf *FoundCharset);
 
+typedef enum __eStreamType {
+	eBase64Encode,
+	eBase64Decode,
+	eZLibEncode,
+	eZLibDecode,
+	eEmtyCodec
+} eStreamType;
+
+typedef struct vStreamT vStreamT;
+vStreamT *StrBufNewStreamContext(eStreamType type, const char **Err);
+int StrBufDestroyStreamContext(eStreamType type, vStreamT **Stream, const char **Err);
+int StrBufStreamTranscode(eStreamType type, IOBuffer *Target, IOBuffer *In, const char* pIn, long pInLen, vStreamT *Stream, int LastChunk, const char **Err);
+
 int StrBufDecodeBase64(StrBuf *Buf);
+int StrBufDecodeBase64To(const StrBuf *BufIn, StrBuf *BufOut);
 int StrBufDecodeHex(StrBuf *Buf);
+StrBuf *StrBufRFC2047encodeMessage(const StrBuf *EncodeMe);
 int StrBufRFC2047encode(StrBuf **target, const StrBuf *source);
 StrBuf *StrBufSanitizeEmailRecipientVector(const StrBuf *Recp, 
 					   StrBuf *UserName, 
@@ -350,8 +366,10 @@ int StrBufSanitizeAscii(StrBuf *Buf, const char Mute);
 #define QU			(3)
 void StrBufUrlescAppend(StrBuf *OutBuf, const StrBuf *In, const char *PlainIn);
 void StrBufUrlescUPAppend(StrBuf *OutBuf, const StrBuf *In, const char *PlainIn);
+void StrBufXMLEscAppend(StrBuf *OutBuf, const StrBuf *In, const char *PlainIn, long PlainInLen, int OverrideLowChars);
 void StrBufHexescAppend(StrBuf *OutBuf, const StrBuf *In, const char *PlainIn);
 void StrBufHexEscAppend(StrBuf *OutBuf, const StrBuf *In, const unsigned char *PlainIn, long PlainInLen);
+void StrBufBase64Append(StrBuf *OutBuf, const StrBuf *In, const char *PlainIn, long PlainInLen, int linebreaks);
 long StrEscAppend(StrBuf *Target, const StrBuf *Source, const char *PlainIn, int nbsp, int nolinebreaks);
 long StrECMAEscAppend(StrBuf *Target, const StrBuf *Source, const char *PlainIn);
 long StrHtmlEcmaEscAppend(StrBuf *Target, const StrBuf *Source, const char *PlainIn, int nbsp, int nolinebreaks);
@@ -441,7 +459,7 @@ char *bmstrcasestr_len(char *text, size_t textlen, const char *pattern, size_t p
 const char *cbmstrcasestr(const char *text, const char *pattern);
 const char *cbmstrcasestr_len(const char *text, size_t textlen, const char *pattern, size_t patlen);
 void CtdlMakeTempFileName(char *name, int len);
-char *rfc2047encode(char *line, long length);
+char *rfc2047encode(const char *line, long length);
 int is_msg_in_mset(const char *mset, long msgnum);
 int pattern2(char *search, char *patn);
 void stripltlen(char *, int *);
